<?php
/**
 * Image Box Elementor Class
 *
 * @package jeg-elementor-kit
 * @author Jegtheme
 * @since 1.1.0
 */

namespace Jeg\Elementor_Kit\Elements\Elementor;

/**
 * Class Image_Box_Elementor
 *
 * @package Jeg\Elementor_Kit\Elements\Elementor
 */
class Image_Box_Elementor extends Elementor_Kit_Abstract {
	/**
	 * Element ID
	 *
	 * @return string
	 */
	public function get_elementor_id() {
		return 'jkit_image_box';
	}
}
