!function(e){var t={};function n(r){if(t[r])return t[r].exports;var o=t[r]={i:r,l:!1,exports:{}};return e[r].call(o.exports,o,o.exports,n),o.l=!0,o.exports}n.m=e,n.c=t,n.d=function(e,t,r){n.o(e,t)||Object.defineProperty(e,t,{enumerable:!0,get:r})},n.r=function(e){"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},n.t=function(e,t){if(1&t&&(e=n(e)),8&t)return e;if(4&t&&"object"==typeof e&&e&&e.__esModule)return e;var r=Object.create(null);if(n.r(r),Object.defineProperty(r,"default",{enumerable:!0,value:e}),2&t&&"string"!=typeof e)for(var o in e)n.d(r,o,function(t){return e[t]}.bind(null,o));return r},n.n=function(e){var t=e&&e.__esModule?function(){return e.default}:function(){return e};return n.d(t,"a",t),t},n.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},n.p="",n(n.s=0)}([function(e,t){class n extends elementorModules.frontend.handlers.Base{getDefaultSettings(){return{selectors:{wrapper:".jeg-elementor-kit.jkit-countdown",days:".timer-container.timer-days",hours:".timer-container.timer-hours",minutes:".timer-container.timer-minutes",seconds:".timer-container.timer-seconds",counts:".timer-container .timer-count"}}}getDefaultElements(){const e=this.getSettings("selectors");return{$wrapper:this.$element.find(e.wrapper),$days:this.$element.find(e.days),$hours:this.$element.find(e.hours),$minutes:this.$element.find(e.minutes),$seconds:this.$element.find(e.seconds),$counts:this.$element.find(e.counts)}}bindEvents(){this.onRender()}onRender(){const e=this,t=new Date(e.elements.$wrapper.data("due-date")).getTime(),n=setInterval((function(){const r=new Date,o=t-r,s=Math.floor(o/864e5),i=Math.floor(o%864e5/36e5),a=Math.floor(o%36e5/6e4),l=Math.floor(o%6e4/1e3);e.elements.$counts.removeClass("timer-loading"),o>=0?(e.elements.$days&&e.elements.$days.find(".timer-count").text(s),e.elements.$hours&&e.elements.$hours.find(".timer-count").text(i),e.elements.$minutes&&e.elements.$minutes.find(".timer-count").text(a),e.elements.$seconds&&e.elements.$seconds.find(".timer-count").text(l)):(clearInterval(n),e.elements.$wrapper.addClass("countdown-expired"),e.onExpired())}),1e3)}onExpired(){const e=this.elements.$wrapper,t=e.data("expired-type");if("message"==t){const t=e.data("expired-title"),n=e.data("expired-content");e.html(`\n        <div class="expire-message">\n          <span class="expire-title">${t}</span>\n          <span class="expire-content">${n}</span>\n        </div>\n      `)}else if("redirect"==t){const t=e.data("redirect-link");window.self!==window.top?e.html(`<div class="expire-message">\n            <span class="expire-content">${iframe_content}</span>\n          </div>\n        `):location.href=t}else if("template"==t){const t=e.data("template");e.html(t)}}}jQuery(window).on("elementor/frontend/init",(()=>{elementorFrontend.hooks.addAction("frontend/element_ready/jkit_countdown.default",(e=>{elementorFrontend.elementsHandler.addHandler(n,{$element:e})}))}))}]);